Amire80 has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/94492


Change subject: Added GENDER support to mobile-frontend-profile-last-edit
......................................................................

Added GENDER support to mobile-frontend-profile-last-edit

Also add "the page" to the original message for clarity.

Change-Id: I5339ea2e6b2d7620ede6a622f1a804ada26901c9
---
M MobileFrontend.i18n.php
M includes/specials/SpecialUserProfile.php
2 files changed, 5 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/MobileFrontend 
refs/changes/92/94492/1

diff --git a/includes/specials/SpecialUserProfile.php 
b/includes/specials/SpecialUserProfile.php
index 1dd45971..83432b9 100644
--- a/includes/specials/SpecialUserProfile.php
+++ b/includes/specials/SpecialUserProfile.php
@@ -121,7 +121,8 @@
                                . Html::openElement( 'div', array( 'class' => 
'caption' ) )
                                . $this->msg( 
'mobile-frontend-profile-last-edit',
                                        $rev->getTitle(),
-                                       $daysAgo
+                                       $daysAgo,
+                                       $this->getUser()->getName()
                                )->parse()
                                . '</div>'
                                . '</div>'

diff --git a/MobileFrontend.i18n.php b/MobileFrontend.i18n.php
index 138c72e..391e244 100644
--- a/MobileFrontend.i18n.php
+++ b/MobileFrontend.i18n.php
@@ -345,7 +345,7 @@
        'mobile-frontend-profile-userpage-link' => 'Visit user page.',
        'mobile-frontend-requires-optin' => 'This page is not available unless 
you opt into our beta mode. Visit the [[Special:MobileOptions|settings page]] 
to opt in.',
        'mobile-frontend-profile-last-thanked' => '{{GENDER:$1|Last thanked}} 
by [[Special:UserProfile/$1|$1]] for an edit to [[$2]].',
-       'mobile-frontend-profile-last-edit' => 'Edited [[$1]], 
{{PLURAL:$2|yesterday|$2 days ago|0=earlier today}}.',
+       'mobile-frontend-profile-last-edit' => '{{GENDER:$3|Edited}} the page 
[[$1]], {{PLURAL:$2|yesterday|$2 days ago|0=earlier today}}.',
        'mobile-frontend-profile-footer-days' => 'Registered for {{PLURAL:$2|1 
day|$2 days}} with [[Special:Contributions/$1|{{PLURAL:$3|1 edit|$3 edits}}]] 
and [[Special:Uploads/$1|{{PLURAL:$4|1 upload|$4 uploads|500=500+ uploads}}]].',
        'mobile-frontend-profile-footer-months' => 'Registered for over 
{{PLURAL:$2|1 month|$2 months}} with [[Special:Contributions/$1|{{PLURAL:$3|1 
edit|$3 edits}}]] and [[Special:Uploads/$1|{{PLURAL:$4|1 upload|$4 
uploads|500=500+ uploads}}]].',
        'mobile-frontend-profile-footer-years' => 'Registered for over 
{{PLURAL:$2|1 year|$2 years}} with [[Special:Contributions/$1|{{PLURAL:$3|1 
edit|$3 edits}}]] and [[Special:Uploads/$1|{{PLURAL:$4|1 upload|$4 
uploads|500=500+ uploads}}]].',
@@ -947,7 +947,8 @@
 
 Parameters:
 * $1 - Name of the page that was edited
 * $2 - How many days ago it was edited.',
        'mobile-frontend-profile-footer-days' => 'Generates the informative 
footer on Special:UserProfile
 
@@ -947,7 +947,8 @@
 Parameters:
 * $1 - Name of the page that was edited
-* $2 - How many days ago it was edited.',
+* $2 - How many days ago it was edited
+* $3 - The username, for GENDER',
        'mobile-frontend-profile-footer-days' => 'Generates the informative 
footer on Special:UserProfile
 Parameters:
-- 
To view, visit https://gerrit.wikimedia.org/r/94492
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I5339ea2e6b2d7620ede6a622f1a804ada26901c9
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/MobileFrontend
Gerrit-Branch: master
Gerrit-Owner: Amire80 <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to